@@ -1,2 +1,2 @@
 from .clients import ContentClient
-from .models import Content
+from .models import BaseContent
